<no title> — CALCEPH - Octave/Matlab language 3.4.1 documentation

    jd0=2442457
    dt=0.5E0

    peph = CalcephBin.open('example1.dat');

    disp('heliocentric coordinates of Mars')
    PV1 = peph.compute_unit(jd0, dt, 4, 11, Constants.UNIT_KM+Constants.UNIT_SEC)

    disp('heliocentric coordinates of Mars')
    PV2 = peph.compute_unit(jd0, dt, NaifId.MARS_BARYCENTER, NaifId.SUN,
                            Constants.UNIT_KM+Constants.UNIT_SEC+Constants.USE_NAIFID)

    peph.close();